@@ -108,10 +108,11 @@ This module is the core commands module.
 
 package Rex::Commands;
 
+use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.8.1'; # VERSION
+our $VERSION = '1.13.4'; # VERSION
 
 require Rex::Exporter;
 use Rex::TaskList;
@@ -122,6 +123,7 @@ use Rex::Report;
 use Rex;
 use Rex::Helper::Misc;
 use Rex::RunList;
+use Symbol;
 
 use Carp;
 
@@ -317,22 +319,16 @@ sub task {
     push( @_, "" );
   }
 
-  no strict 'refs'; ## no critic ProhibitNoStrict
-  no warnings;
-  push( @{"${class}::tasks"}, { name => $task_name_save, code => $_[-2] } );
-  use strict;
-  use warnings;
-
   $options->{'dont_register'} ||= $dont_register_tasks;
   my $task_o = Rex::TaskList->create()->create_task( $task_name, @_, $options );
 
   if (!$class->can($task_name_save)
     && $task_name_save =~ m/^[a-zA-Z_][a-zA-Z0-9_]+$/ )
   {
-    no strict 'refs'; ## no critic ProhibitNoStrict
     Rex::Logger::debug("Registering task: $task_name");
-    my $code = $_[-2];
-    *{"${class}::$task_name_save"} = sub {
+    my $code        = $_[-2];
+    my $ref_to_task = qualify_to_ref( $task_name_save, $class );
+    *{$ref_to_task} = sub {
       Rex::Logger::info("Running task $task_name on current connection");
       my $param;
 
@@ -379,7 +375,9 @@ Or with the expression syntax:
 
  group "servergroup", "www[1..3]", "memcache[01..03]";
 
-You can also specify server options after a server name with a hash reference:
+If the C<use_server_auth> feature flag is enabled, you can also specify server options after a server name with a hash reference:
+
+ use Rex -feature => ['use_server_auth'];
 
  group "servergroup", "www1" => { user => "other" }, "www2";
 
@@ -496,16 +494,16 @@ sub password {
 
 =head2 auth(for => $entity, %data)
 
-With this function you can modify/set special authentication parameters for tasks and groups.
-If you want to modify a group's authentication you first have to create it.
-(Place the auth command after the group.)
+With this command you can set or modify authentication parameters for tasks and groups. (Please note this is different than setting authentication details for the members of a host group. If you are looking for that, please check out the L<group|https://metacpan.org/pod/Rex::Commands#group> command.)
 
-If you want to set special login information for a group you have to activate that feature first.
+If you want to set special login information for a group you have to enable at least the C<0.31> feature flag, and ensure the C<group> is declared before the C<auth> command.
 
- use Rex -feature => 0.31; # activate setting auth for a group
+Command line options to set locality or authentication details are still taking precedence, and may override these settings.
 
  # auth for groups
  
+ use Rex -feature => ['0.31']; # activate setting auth for a group
+
  group frontends => "web[01..10]";
  group backends => "be[01..05]";
  
@@ -1079,7 +1077,9 @@ sub needs {
 }
 
 # register needs in main namespace
-{
+_register_needs_in_main_namespace();
+
+sub _register_needs_in_main_namespace {
   my ($caller_pkg) = caller(1);
 
   if ( !$caller_pkg ) {
@@ -1087,11 +1087,10 @@ sub needs {
   }
 
   if ( $caller_pkg && ( $caller_pkg eq "Rex::CLI" || $caller_pkg eq "main" ) ) {
-    no strict 'refs'; ## no critic ProhibitNoStrict
-    *{"main::needs"} = \&needs;
-    use strict;
+    my $ref_to_needs = qualify_to_ref( 'needs', 'main' );
+    *{$ref_to_needs} = \&needs;
   }
-};
+}
 
 =head2 include Module::Name
 
@@ -1202,7 +1201,7 @@ With the LOCAL function you can do local commands within a task that is defined
 
 =cut
 
-sub LOCAL (&) { ## no critic ProhibitSubroutinePrototypes
+sub LOCAL (&) {
   my $cur_conn      = Rex::get_current_connection();
   my $local_connect = Rex::Interface::Connection->create("Local");
 
@@ -1298,13 +1297,16 @@ sub get {
 
 =head2 before($task => sub {})
 
-Run code before executing the specified task. The special taskname 'ALL' can be used to run code before all tasks.
+Run code before executing the specified task.
+
+The task name is a regular expression to find all tasks with a matching name. The special task name C<'ALL'> can also be used to run code before all tasks.
+
 If called repeatedly, each sub will be appended to a list of 'before' functions.
 
 In this hook you can overwrite the server to which the task will connect to. The second argument is a reference to the 
 server object that will be used for the connection.
 
-Note: must come after the definition of the specified task
+Please note, this must come after the definition of the specified task.
 
  before mytask => sub {
   my ($server, $server_ref, $cli_args) = @_;
@@ -1327,10 +1329,13 @@ sub before {
 
 =head2 after($task => sub {})
 
-Run code after the task is finished. The special taskname 'ALL' can be used to run code after all tasks.
+Run code after executing the specified task.
+
+The task name is a regular expression to find all tasks with a matching name. The special task name C<'ALL'> can be used to run code after all tasks.
+
 If called repeatedly, each sub will be appended to a list of 'after' functions.
 
-Note: must come after the definition of the specified task
+Please note, this must come after the definition of the specified task.
 
  after mytask => sub {
   my ($server, $failed, $cli_args) = @_;
@@ -1356,13 +1361,16 @@ sub after {
 
 =head2 around($task => sub {})
 
-Run code before and after the task is finished. The special taskname 'ALL' can be used to run code around all tasks.
+Run code around the specified task (that is both before and after executing it).
+
+The task name is a regular expression to find all tasks with a matching name. The special task name C<'ALL'> can be used to run code around all tasks.
+
 If called repeatedly, each sub will be appended to a list of 'around' functions.
 
 In this hook you can overwrite the server to which the task will connect to. The second argument is a reference to the 
 server object that will be used for the connection.
 
-Note: must come after the definition of the specified task
+Please note, this must come after the definition of the specified task.
 
  around mytask => sub {
   my ($server, $server_ref, $cli_args, $position) = @_;
@@ -1392,10 +1400,13 @@ sub around {
 
 =head2 before_task_start($task => sub {})
 
-Run code before executing the specified task. This gets executed only once for a task. The special taskname 'ALL' can be used to run code before all tasks.
+Run code before executing the specified task. This gets executed only once for a task.
+
+The task name is a regular expression to find all tasks with a matching name. The special task name C<'ALL'> can be used to run code before all tasks.
+
 If called repeatedly, each sub will be appended to a list of 'before_task_start' functions.
 
-Note: must come after the definition of the specified task
+Please note, this must come after the definition of the specified task.
 
  before_task_start mytask => sub {
    # do some things
@@ -1417,10 +1428,13 @@ sub before_task_start {
 
 =head2 after_task_finished($task => sub {})
 
-Run code after the task is finished (and after the ssh connection is terminated). This gets executed only once for a task. The special taskname 'ALL' can be used to run code before all tasks.
+Run code after the task is finished (and after the ssh connection is terminated). This gets executed only once for a task.
+
+The task name is a regular expression to find all tasks with a matching name. The special task name C<'ALL'> can be used to run code after all tasks.
+
 If called repeatedly, each sub will be appended to a list of 'after_task_finished' functions.
 
-Note: must come after the definition of the specified task
+Please note, this must come after the definition of the specified task.
 
  after_task_finished mytask => sub {
    # do some things
@@ -1570,17 +1584,17 @@ sub last_command_output {
 This is a function to compare a string with some given options.
 
  task "mytask", "myserver", sub {
-   my $ntp_service = case operating_sytem, {
+   my $ntp_service = case operating_system, {
                  Debian  => "ntp",
                  default => "ntpd",
                };
 
-   my $ntp_service = case operating_sytem, {
+   my $ntp_service = case operating_system, {
                  qr{debian}i => "ntp",
                  default    => "ntpd",
                };
 
-   my $ntp_service = case operating_sytem, {
+   my $ntp_service = case operating_system, {
                  qr{debian}i => "ntp",
                  default    => sub { return "foo"; },
                };
@@ -1938,7 +1952,7 @@ sub FALSE {
   return 0;
 }
 
-sub make(&) { ## no critic ProhibitSubroutinePrototypes
+sub make(&) {
   return $_[0];
 }
 
