@@ -6,14 +6,11 @@
 
 package Rex::Service::SuSE::systemd;
 
+use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
-
-use Rex::Commands::Run;
-use Rex::Logger;
-use Rex::Commands::Fs;
+our $VERSION = '1.13.4'; # VERSION
 
 use Rex::Service::Redhat::systemd;
 use base qw(Rex::Service::Redhat::systemd);
